package com.example;

import org.jbpm.api.Configuration;
import org.jbpm.api.Execution;
import org.jbpm.api.ExecutionService;
import org.jbpm.api.ProcessEngine;
import org.jbpm.api.ProcessInstance;
import org.jbpm.api.RepositoryService;

public class App {

	public static void main(String[] args) {
		/*
		 * Create process engine from configuration. Here the configuration
		 * object represents default jbpm.cfg.xml file.
		 */
		ProcessEngine processEngine = Configuration.getProcessEngine();

		/*
		 * Repository service provides access to resources that are known to
		 * JBPM, including loaded processes.
		 */
		RepositoryService repositoryService = processEngine
				.getRepositoryService();

		/*
		 * Execution service is the handle to execute state transitions in
		 * process engine.
		 */
		ExecutionService executionService = processEngine.getExecutionService();

		/*
		 * Now query repository service for the process that we have created and
		 * deploy it.
		 */
		repositoryService.createDeployment().addResourceFromClasspath(
				"process.jpdl.xml").deploy();

		/*
		 * Start the process instance with the name of the process. By starting
		 * process, new ProcessInstance object is created. In our example flow,
		 * after the initial state, there is 'java' state that gets executed and
		 * the transition continues to next 'state' where it waits to be
		 * commanded.
		 */
		ProcessInstance processInstance = executionService
				.startProcessInstanceByKey("Activity");

		/*
		 * We are now in 'state' named 'proceed to end'. We must ask process
		 * instance to find active execution in this particular state.
		 */
		Execution execution = processInstance
				.findActiveExecutionIn("proceed to end");

		/*
		 * Finally we ask execution service to signal that transition from the
		 * state shall occur. By this, the rest of the process is executed and
		 * the flow ends.
		 */
		processInstance = executionService.signalExecutionById(execution
				.getId());
	}
}
